==> nextcloud-31.0.9.tgz: nextcloud/apps/bruteforcesettings/l10n/et_EE.js <==
OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Jõuründe piiramise meetmete seadistused",
    "Whitelist IPs" : "Lubatud IP-aadressid",
    "Your remote address was identified as \"{remoteAddress}\" and is throttled at the moment by {delay}ms." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle puhul on hetkel jõuründe piiramise meetmena kasutusel {delay}-millisekundiline viivitus.",
    "Your remote address was identified as \"{remoteAddress}\" and is bypassing brute-force protection." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle puhul on hetkel ei kehti jõuründe piiramise meetmed.",
    "Your remote address was identified as \"{remoteAddress}\" and is not actively throttled at the moment." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle puhul on hetkel ei kasutada jõuründe piiramise meetmena päringute viivitamist.",
    "There was an error adding the IP to the whitelist." : "IP-aadressi lisamisel lubatud aadresside loendisse tekkis viga.",
    "Brute-force IP whitelist" : "Lubatud IP-aadresside loend, kus jõuründe piiramise meetmed ei kehti",
    "Apply whitelist to rate limit" : "Kasuta lubatud aadresside loendit päringute sageduse piiramisel",
    "Add a new whitelist" : "Koosta uus lubatud aadresside loend, kus jõuründe piiramise meetmed ei kehti",
    "IP address" : "IP-address",
    "Mask" : "Aadressi mask",
    "Add" : "Lisa",
    "Delete entry for {subnet}" : "Kustuta „{subnet}“ kirje"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.10.tgz: nextcloud/apps/bruteforcesettings/l10n/et_EE.js <==
OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Jõuründe piiramise meetmete seadistused",
    "Whitelist IPs" : "Lubatud IP-aadressid",
    "Your remote address was identified as \"{remoteAddress}\" and is throttled at the moment by {delay}ms." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle puhul on hetkel jõuründe piiramise meetmena kasutusel {delay}-millisekundiline viivitus.",
    "Your remote address was identified as \"{remoteAddress}\" and is bypassing brute-force protection." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle puhul on hetkel ei kehti jõuründe piiramise meetmed.",
    "Your remote address was identified as \"{remoteAddress}\" and is not actively throttled at the moment." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle puhul on hetkel ei kasutada jõuründe piiramise meetmena päringute viivitamist.",
    "There was an error adding the IP to the whitelist." : "IP-aadressi lisamisel lubatud aadresside loendisse tekkis viga.",
    "Brute-force IP whitelist" : "Lubatud IP-aadresside loend, kus jõuründe piiramise meetmed ei kehti",
    "To whitelist IP ranges from the brute-force protection specify them below. Note that any whitelisted IP can perform authentication attempts without any throttling. For security reasons, it is recommended to whitelist as few hosts as possible or ideally even none at all." : "Välistamaks konkreetseid IP-aadressivahemikke jõuründe piiramise meetmete alt, saad nad sisestada siia. Palun arvesta, et kõikidelt siia loendisse lisatud aadressidelt on võimalik teha autentimispäringuid piiramata arvus ja viisil. Turvakaalutlustel palun hoia see loend võimalikult napina või ideaalis sootuks tühjana.",
    "Apply whitelist to rate limit" : "Kasuta lubatud aadresside loendit päringute sageduse piiramisel",
    "Add a new whitelist" : "Koosta uus lubatud aadresside loend, kus jõuründe piiramise meetmed ei kehti",
    "IP address" : "IP-address",
    "Mask" : "Aadressi mask",
    "Add" : "Lisa",
    "Delete entry for {subnet}" : "Kustuta „{subnet}“ kirje"
},
"nplurals=2; plural=(n != 1);");
